import { Section, SectionCard } from '@blueprintjs/core'
import { useLiveQuery } from 'dexie-react-hooks'
import { memo, useEffect, useState, type FC } from 'react'
import { db } from '../indexeddb/db'
import EmailChannelForm from './EmailChannelForm'
import ExerciseDurationForm from './ExerciseDurationForm'
import InfoChannelForm from './InfoChannelForm'
import ToolChannelForm from './ToolChannelForm'

interface FinalInformationFormProps {
  onInputChange: (isZero: boolean) => void
}

const FinalInformationForm: FC<FinalInformationFormProps> = ({
  onInputChange,
}) => {
  const emailAddressesCount = useLiveQuery(
    () => db.emailAddresses.count(),
    [],
    0
  )
  const toolsCount = useLiveQuery(() => db.tools.count(), [], 0)
  const [isDurationZero, setIsDurationZero] = useState(true)

  useEffect(() => {
    onInputChange(isDurationZero)
  }, [isDurationZero])

  return (
    <div>
      <Section title='Exercise details'>
        <SectionCard>
          <ExerciseDurationForm
            onInputChange={duration => setIsDurationZero(duration === 0)}
          />
        </SectionCard>
      </Section>
      <Section title='Channel details'>
        <SectionCard>
          <InfoChannelForm />
          {toolsCount > 0 && <ToolChannelForm />}
          {emailAddressesCount > 0 && <EmailChannelForm />}
        </SectionCard>
      </Section>
    </div>
  )
}

export default memo(FinalInformationForm)
