import Dexie, { type EntityTable } from 'dexie'
import type {
  EmailAddressInfo,
  EmailTemplate,
  InjectInfo,
  LearningActivityInfo,
  LearningObjectiveInfo,
  ToolInfo,
  ToolResponse,
} from './types'

const dbName = 'EditorDatabase'
const dbVersion = 1

const db = new Dexie(dbName) as Dexie & {
  learningObjectives: EntityTable<LearningObjectiveInfo, 'id'>
  learningActivities: EntityTable<LearningActivityInfo, 'id'>
  injectInfos: EntityTable<InjectInfo, 'id'>
  tools: EntityTable<ToolInfo, 'id'>
  toolResponses: EntityTable<ToolResponse, 'id'>
  emailAddresses: EntityTable<EmailAddressInfo, 'id'>
  emailTemplates: EntityTable<EmailTemplate, 'id'>
}

db.version(dbVersion).stores({
  learningObjectives: '++id, &name',
  learningActivities: '++id, &name, description, type, learningObjectiveId',
  injectInfos: '++id, &name, description, type',
  tools: '++id, &name, tooltipDescription, hint, defaultResponse, category',
  toolResponses:
    '++id, &learningActivityId, toolId, parameter, isRegex, content', // TODO file
  emailAddresses: '++id, address, organization, description, teamVisible',
  emailTemplates: '++id, &learningActivityId, emailAddressId, context, content', // TODO file
})

export { db }
